# PyKrev: van Krevelen analysis and beyond

PyKrev is a Python 3 library to help with analysis of high resolution mass spectrometry data.

To install use:

```
pip install pykrev
```

[**The User Guide can be accessed here**](https://nbviewer.jupyter.org/github/Kzra/pykrev/blob/master/docs/user_guide/PyKrevUserGuide.ipynb)

[*Making UpSet plots with PyKrev and UpSetPlot*](https://nbviewer.jupyter.org/github/Kzra/pykrev/blob/master/docs/upset_plots_with_pykrev/UpSetplotswithPyKrev.ipynb)

[*Performing PCA with PyKrev and scikit-learn*](https://nbviewer.jupyter.org/github/Kzra/pykrev/blob/master/docs/pca_with_pykrev/PCAwithPyKrev.ipynb)

Version 1.1.0 [*Changelog*](https://github.com/Kzra/pykrev/blob/master/CHANGELOG.md)

Please send any feedback or comments to ezra.kitson@ed.ac.uk

<img src="https://github.com/Kzra/pykrev/blob/master/docs/user_guide/Pykrev_blue.png" alt="PyKrev" width="650"/>
